==> qtirreco_0.3.0-1.tar.gz: qtirreco-0.3.0/src/remotestartupdlg.cpp <==
#include "remotestartupdlg.h"
#include "ui_remotestartupdlg.h"

RemoteStartupDlg::RemoteStartupDlg(QString aRemoteName, QWidget *parent, QStringList *remotes) :
    QDialog(parent),
    m_ui(new Ui::RemoteStartupDlg)
{
    m_ui->setupUi(this);
    this->setObjectName("remoteStartupDlg");
    remoteNames = remotes;
    themeUsed.clear();
    customTheme = false;
    this->setWindowTitle("Select buttons for remote");
    flag = false;
    raw_flag = false;
    remoteName = aRemoteName;
    QDir dir;
    homePath = dir.currentPath();
    loadRemote();

    connect(m_ui->addedButtonslistWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(removeFromSelectedList(QListWidgetItem*)));
    connect(m_ui->buttonlistWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(itemClicked(QListWidgetItem*)));
}

RemoteStartupDlg::~RemoteStartupDlg()
{
    delete m_ui;
}

void RemoteStartupDlg::process_line(QString line)
{
    if(!line.startsWith("#",Qt::CaseInsensitive)) {
        if(line.contains(("end codes"), Qt::CaseInsensitive)) {
               flag = false;
               this->makeButtons();
            }

        if(line.contains(("end raw_codes"), Qt::CaseInsensitive)) {
               flag = false;
               this->makeButtons();
            }
        if(flag) {
            QString buttonName = line;
            int lineLength;
            QString finalButtonName;

            buttonName = buttonName.trimmed();
            lineLength = buttonName.length();

            for (int i=0;i<lineLength;i++) {
                if(buttonName.at(i).isSpace() == false)
                     finalButtonName.append(buttonName.at(i));

                 if(buttonName.at(i).isSpace() == true)
                     break;
            }
            buttonNames.append(finalButtonName);
        }
        if(raw_flag) {
             if(line.contains(("name"), Qt::CaseInsensitive)) {
                line = line.trimmed();
                line.remove(0,5);
                buttonNames.append(line);
             }
        }
        if(line.contains(("begin codes"), Qt::CaseInsensitive))
            flag = true;

        if(line.contains(("begin raw_codes"), Qt::CaseInsensitive))
            raw_flag = true;

    }
}

void RemoteStartupDlg::loadRemote()
{
    m_ui->remoteNameLineEdit->setText(remoteName);

    QFile file(devicesPath + remoteName);
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
    return;

    QTextStream in(&file);
    while (!in.atEnd()) {
        QString line = in.readLine();
        process_line(line);
    }
    QDir dir;
    dir.setCurrent(homePath);
}

void RemoteStartupDlg::itemClicked(QListWidgetItem* item)
{
    m_ui->addedButtonslistWidget->insertItem(0, item->text());
    m_ui->addedButtonslistWidget->sortItems(Qt::AscendingOrder);
    delete m_ui->buttonlistWidget->currentItem();
}

void RemoteStartupDlg::removeFromSelectedList(QListWidgetItem* item)
{
     m_ui->selectAllButtons->setText("Select\nall buttons");
     m_ui->buttonlistWidget->insertItem(0, item->text());
     m_ui->buttonlistWidget->sortItems(Qt::AscendingOrder);
     delete m_ui->addedButtonslistWidget->currentItem();
}

void RemoteStartupDlg::makeButtons()
{
    m_ui->buttonlistWidget->insertItems(0, buttonNames);
    m_ui->buttonlistWidget->sortItems(Qt::AscendingOrder);
}

void RemoteStartupDlg::on_pushButton_clicked()
{
    bool sameName = false;
    if(!remoteNames->isEmpty() && !m_ui->remoteNameLineEdit->text().isEmpty()) {

          for(int i=0; i<remoteNames->count(); i++) {
              QString name = remoteNames->at(i);
              name.chop(5);
              if(name == m_ui->remoteNameLineEdit->text()) {
                  sameName = true;
                  QMessageBox::warning(this,"Remote name already exists!","Cannot create remote with existing name.",
                  QMessageBox::NoButton,QMessageBox::NoButton);
              }
          }
      }

    if(!sameName && !m_ui->remoteNameLineEdit->text().isEmpty()) {

        if(customTheme) {
            // Open theme manager and ask which theme wanted to use in buttons.
            themeDlg = new ThemeManager(this);
            themeDlg->setRemoteStartupProperties();
            connect(themeDlg,SIGNAL(themeChoosed(QString)),this,SLOT(setThemeName(QString)));
            themeDlg->exec();
            if(themeUsed.isEmpty()){
                this->close();
                return;
            }
        }
        emit lwClear();
        if(m_ui->addedButtonslistWidget->count() > 0) {
            QString buttonTextToEmit;
            QStringList aCommand;
            for(int i = 0; i < m_ui->addedButtonslistWidget->count() ; i++) {
                buttonTextToEmit = m_ui->addedButtonslistWidget->item(i)->text();
                aCommand.append(remoteName + " " +  m_ui->addedButtonslistWidget->item(i)->text());

                if(customTheme) {
                    this->setButtonPath(buttonTextToEmit);
                    emit addButtonToLayoutSignalFromRSD(fileNameUnpressed, fileNamePressed, confFileName, buttonTextToEmit, aCommand, i);
                }
                else emit addButtonToLayoutSignalFromRSD(buttonTextToEmit, buttonTextToEmit, buttonTextToEmit, buttonTextToEmit, aCommand, i);

                aCommand.clear();
                fileNameUnpressed.clear();
                fileNamePressed.clear();
                confFileName.clear();
            }
        }
        emit remoteCreated(m_ui->remoteNameLineEdit->text());
        this->close();
    }

}
void RemoteStartupDlg::setThemeName(const QString &themeName)
{
    themeUsed = themeName;
}

void RemoteStartupDlg::on_selectThemeButton_clicked()
{
    customTheme = true;
    this->on_pushButton_clicked();
}
void RemoteStartupDlg::setButtonPath(const QString &buttonText)
{
   // First get chosen theme buttonlist.
   QStringList themeButtonsList;
   QDir themeButtons(themesPath + themeUsed + "/buttons/");
   themeButtonsList = themeButtons.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
   // Check if button text matches with button folder.
   QString button;

   for(int i = 0; i < themeButtonsList.count(); i++) {

    button = themeButtonsList.at(i);
    // Check if buttonText contains number, then compare if theme buttons contains any folder which has number.
    bool ok;
    int num = buttonText.toInt(&ok,10);
    Q_UNUSED(num);
    if(ok) {
        if(button.contains(buttonText,Qt::CaseInsensitive)) {
             fileNameUnpressed = themesPath + themeUsed + "/buttons/" + button + "/unpressed.png";
             fileNamePressed = themesPath + themeUsed + "/buttons/" + button + "/pressed.png";
             confFileName = themesPath + themeUsed + "/buttons/" + button + "/button.conf";
             return;
        }
    }

    // Else compare strict.
       if(QString::compare(button,buttonText,Qt::CaseInsensitive) == 0) {
            fileNameUnpressed = themesPath + themeUsed + "/buttons/" + button + "/unpressed.png";
            fileNamePressed = themesPath + themeUsed + "/buttons/" + button + "/pressed.png";
            confFileName = themesPath + themeUsed + "/buttons/" + button + "/button.conf";
            return;
       }
    }
    // If no match use blank button.
   fileNameUnpressed = themesPath + themeUsed + "/buttons/blank/unpressed.png";
   fileNamePressed = themesPath + themeUsed + "/buttons/blank/pressed.png";
   confFileName = themesPath + themeUsed + "/buttons/blank/button.conf";


}

void RemoteStartupDlg::on_selectAllButtons_clicked()
{
    if(m_ui->selectAllButtons->text() == "Select\nall buttons") {
        while(m_ui->buttonlistWidget->count() != 0)
            m_ui->addedButtonslistWidget->insertItem(0,m_ui->buttonlistWidget->takeItem(0));

        m_ui->addedButtonslistWidget->sortItems(Qt::AscendingOrder);
        m_ui->selectAllButtons->setText("Remove\nall buttons");
        return;
    }
    else if(m_ui->selectAllButtons->text() == "Remove\nall buttons") {
        while(m_ui->addedButtonslistWidget->count() != 0)
            m_ui->buttonlistWidget->insertItem(0,m_ui->addedButtonslistWidget->takeItem(0));

        m_ui->buttonlistWidget->sortItems(Qt::AscendingOrder);
        m_ui->selectAllButtons->setText("Select\nall buttons");
    }
}

==> qtirreco_0.3.1-1.tar.gz: qtirreco-0.3.1/src/remotestartupdlg.cpp <==
#include "remotestartupdlg.h"
#include "ui_remotestartupdlg.h"

RemoteStartupDlg::RemoteStartupDlg(QString aRemoteName, QWidget *parent, QStringList *remotes) :
    QDialog(parent),
    m_ui(new Ui::RemoteStartupDlg)
{
    m_ui->setupUi(this);
    this->setObjectName("remoteStartupDlg");
    remoteNames = remotes;
    themeUsed.clear();
    customTheme = false;
    this->setWindowTitle("Select buttons for remote");
    flag = false;
    raw_flag = false;
    remoteName = aRemoteName;
    QDir dir;
    homePath = dir.currentPath();
    loadRemote();

    connect(m_ui->addedButtonslistWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(removeFromSelectedList(QListWidgetItem*)));
    connect(m_ui->buttonlistWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(itemClicked(QListWidgetItem*)));
}

RemoteStartupDlg::~RemoteStartupDlg()
{
    delete m_ui;
}

void RemoteStartupDlg::process_line(QString line)
{
    if(!line.startsWith("#",Qt::CaseInsensitive)) {
        if(line.contains(("end codes"), Qt::CaseInsensitive)) {
               flag = false;
               this->makeButtons();
            }

        if(line.contains(("end raw_codes"), Qt::CaseInsensitive)) {
               flag = false;
               this->makeButtons();
            }
        if(flag) {
            QString buttonName = line;
            int lineLength;
            QString finalButtonName;

            buttonName = buttonName.trimmed();
            lineLength = buttonName.length();

            for (int i=0;i<lineLength;i++) {
                if(buttonName.at(i).isSpace() == false)
                     finalButtonName.append(buttonName.at(i));

                 if(buttonName.at(i).isSpace() == true)
                     break;
            }
            buttonNames.append(finalButtonName);
        }
        if(raw_flag) {
             if(line.contains(("name"), Qt::CaseInsensitive)) {
                line = line.trimmed();
                line.remove(0,5);
                buttonNames.append(line);
             }
        }
        if(line.contains(("begin codes"), Qt::CaseInsensitive))
            flag = true;

        if(line.contains(("begin raw_codes"), Qt::CaseInsensitive))
            raw_flag = true;

    }
}

void RemoteStartupDlg::loadRemote()
{
    m_ui->remoteNameLineEdit->setText(remoteName);

    QFile file(devicesPath + remoteName);
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
    return;

    QTextStream in(&file);
    while (!in.atEnd()) {
        QString line = in.readLine();
        process_line(line);
    }
    QDir dir;
    dir.setCurrent(homePath);
}

void RemoteStartupDlg::itemClicked(QListWidgetItem* item)
{
    m_ui->addedButtonslistWidget->insertItem(0, item->text());
    m_ui->addedButtonslistWidget->sortItems(Qt::AscendingOrder);
    delete m_ui->buttonlistWidget->currentItem();
}

void RemoteStartupDlg::removeFromSelectedList(QListWidgetItem* item)
{
     m_ui->selectAllButtons->setText("Select\nall buttons");
     m_ui->buttonlistWidget->insertItem(0, item->text());
     m_ui->buttonlistWidget->sortItems(Qt::AscendingOrder);
     delete m_ui->addedButtonslistWidget->currentItem();
}

void RemoteStartupDlg::makeButtons()
{
    m_ui->buttonlistWidget->insertItems(0, buttonNames);
    m_ui->buttonlistWidget->sortItems(Qt::AscendingOrder);
}

void RemoteStartupDlg::on_pushButton_clicked()
{
    bool sameName = false;
    if(!remoteNames->isEmpty() && !m_ui->remoteNameLineEdit->text().isEmpty()) {

          for(int i=0; i<remoteNames->count(); i++) {
              QString name = remoteNames->at(i);
              name.chop(5);
              if(name == m_ui->remoteNameLineEdit->text()) {
                  sameName = true;
                  QMessageBox::warning(this,"Remote name already exists!","Cannot create remote with existing name.",
                  QMessageBox::NoButton,QMessageBox::NoButton);
              }
          }
      }

    if(!sameName && !m_ui->remoteNameLineEdit->text().isEmpty()) {

        if(customTheme) {
            // Open theme manager and ask which theme wanted to use in buttons.
            themeDlg = new ThemeManager(this);
            themeDlg->setRemoteStartupProperties();
            connect(themeDlg,SIGNAL(themeChoosed(QString)),this,SLOT(setThemeName(QString)));
            themeDlg->exec();
            if(themeUsed.isEmpty()){
                this->close();
                return;
            }
        }
        emit lwClear();
        if(m_ui->addedButtonslistWidget->count() > 0) {
            QString buttonTextToEmit;
            QStringList aCommand;
            for(int i = 0; i < m_ui->addedButtonslistWidget->count() ; i++) {
                buttonTextToEmit = m_ui->addedButtonslistWidget->item(i)->text();
                aCommand.append(remoteName + " " +  m_ui->addedButtonslistWidget->item(i)->text());

                if(customTheme) {
                    this->setButtonPath(buttonTextToEmit);
                    emit addButtonToLayoutSignalFromRSD(fileNameUnpressed, fileNamePressed, confFileName, buttonTextToEmit, aCommand, i);
                }
                else emit addButtonToLayoutSignalFromRSD(buttonTextToEmit, buttonTextToEmit, buttonTextToEmit, buttonTextToEmit, aCommand, i);

                aCommand.clear();
                fileNameUnpressed.clear();
                fileNamePressed.clear();
                confFileName.clear();
            }
        }
        emit remoteCreated(m_ui->remoteNameLineEdit->text());
        this->close();
    }

}
void RemoteStartupDlg::setThemeName(const QString &themeName)
{
    themeUsed = themeName;
}

void RemoteStartupDlg::on_selectThemeButton_clicked()
{
    customTheme = true;
    this->on_pushButton_clicked();
}
void RemoteStartupDlg::setButtonPath(const QString &buttonText)
{
   // First get chosen theme buttonlist.
   QStringList themeButtonsList;
   QDir themeButtons(themesPath + themeUsed + "/buttons/");
   themeButtonsList = themeButtons.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
   // Check if button text matches with button folder.
   QString button;

   for(int i = 0; i < themeButtonsList.count(); i++) {

    button = themeButtonsList.at(i);
    // Check if buttonText contains number, then compare if theme buttons contains any folder which has number.
    bool ok;
    int num = buttonText.toInt(&ok,10);
    Q_UNUSED(num);
    if(ok) {
        if(button.contains((buttonText),Qt::CaseInsensitive)) {
             fileNameUnpressed = themesPath + themeUsed + "/buttons/" + button + "/unpressed.png";
             fileNamePressed = themesPath + themeUsed + "/buttons/" + button + "/pressed.png";
             confFileName = themesPath + themeUsed + "/buttons/" + button + "/button.conf";
             return;
        }
    }

    // Else compare strict.
       if(QString::compare(button,buttonText,Qt::CaseInsensitive) == 0) {
            fileNameUnpressed = themesPath + themeUsed + "/buttons/" + button + "/unpressed.png";
            fileNamePressed = themesPath + themeUsed + "/buttons/" + button + "/pressed.png";
            confFileName = themesPath + themeUsed + "/buttons/" + button + "/button.conf";
            return;
       }
    }
    // If no match use blank button.
   fileNameUnpressed = themesPath + themeUsed + "/buttons/blank/unpressed.png";
   fileNamePressed = themesPath + themeUsed + "/buttons/blank/pressed.png";
   confFileName = themesPath + themeUsed + "/buttons/blank/button.conf";


}

void RemoteStartupDlg::on_selectAllButtons_clicked()
{
    if(m_ui->selectAllButtons->text() == "Select\nall buttons") {
        while(m_ui->buttonlistWidget->count() != 0)
            m_ui->addedButtonslistWidget->insertItem(0,m_ui->buttonlistWidget->takeItem(0));

        m_ui->addedButtonslistWidget->sortItems(Qt::AscendingOrder);
        m_ui->selectAllButtons->setText("Remove\nall buttons");
        return;
    }
    else if(m_ui->selectAllButtons->text() == "Remove\nall buttons") {
        while(m_ui->addedButtonslistWidget->count() != 0)
            m_ui->buttonlistWidget->insertItem(0,m_ui->addedButtonslistWidget->takeItem(0));

        m_ui->buttonlistWidget->sortItems(Qt::AscendingOrder);
        m_ui->selectAllButtons->setText("Select\nall buttons");
    }
}
